@@ -21,6 +21,8 @@ import pwd
 import gtk
 import gtk.glade
 import userdb
+import errors
+import debuglog
 
 from config import *
 
@@ -56,7 +58,7 @@ class UsersDialog:
         apply_to_all = self.userdb.get_default_profile (False) == profile
         
         glade_file = os.path.join (GLADEDIR, "sabayon.glade")
-        self.xml = gtk.glade.XML (glade_file, "users_dialog")
+        self.xml = gtk.glade.XML (glade_file, "users_dialog", PACKAGE)
 
         self.dialog = self.xml.get_widget ("users_dialog")
         self.dialog.set_transient_for (parent)
@@ -98,6 +100,7 @@ class UsersDialog:
         response = self.dialog.run ()
         self.dialog.hide ()
 
+    @errors.checked_callback (debuglog.DEBUG_LOG_DOMAIN_USER)
     def __on_use_toggled (self, toggle, path):
         iter = self.users_model.get_iter_from_string (path)
         apply = self.users_model.get_value (iter, UsersModel.COLUMN_APPLY)
@@ -113,6 +116,7 @@ class UsersDialog:
         else:
             self.userdb.set_profile (username, None)
 
+    @errors.checked_callback (debuglog.DEBUG_LOG_DOMAIN_USER)
     def __all_check_toggled (self, toggle):
         apply_to_all = self.all_check.get_active ()
         self.users_list.set_sensitive (not apply_to_all)
