@@ -39,7 +39,7 @@ def recursive_del (path):
         return
 
     if os.path.isdir (path):
-	for file in os.listdir (path):
+        for file in os.listdir (path):
             subpath = os.path.join (path, file)
             recursive_del (subpath)
         os.rmdir (path)
@@ -73,10 +73,10 @@ def copy_tree (dst_base, src_base, dst_name, src_name = None, overwrite = False)
 def unlink_children(node):
     children = node.children
     while children:
-	  tmp = children
-	  children = children.next
-	  tmp.unlinkNode()
-	  tmp.freeNode()
+        tmp = children
+        children = children.next
+        tmp.unlinkNode()
+        tmp.freeNode()
 
 class ProfileStorageException (Exception):
     pass
@@ -107,23 +107,23 @@ class ProfileStorage:
         /etc/desktop-profiles/$(name).zip.
         """
         self.name = name
-	self.readonly = 0
+        self.readonly = 0
 
         if not os.path.isabs (self.name):
-	    try:
-	        protocol = urlparse.urlparse(self.name)[0]
-	        if protocol == "":
-		    self.path = os.path.join (PROFILESDIR, self.name + ".zip")
-		else:
-		    # if someone uses file:/// they deserve to have troubles
-		    self.readonly == 1
-		    cachou = cache.get_default_cache()
-		    self.path = cachou.get_resource(self.name)
-		    if self.path == None:
-		        self.path = self.name
+            try:
+                protocol = urlparse.urlparse(self.name)[0]
+                if protocol == "":
+                    self.path = os.path.join (PROFILESDIR, self.name + ".zip")
+                else:
+                    # if someone uses file:/// they deserve to have troubles
+                    self.readonly == 1
+                    cachou = cache.get_default_cache()
+                    self.path = cachou.get_resource(self.name)
+                    if self.path == None:
+                        self.path = self.name
 
-	    except:
-		self.path = os.path.join (PROFILESDIR, self.name + ".zip")
+            except:
+                self.path = os.path.join (PROFILESDIR, self.name + ".zip")
         else:
             self.path = name
 
@@ -564,7 +564,7 @@ class ProfileStorage:
         """Save the contents of the profile to
         /etc/desktop-profiles/$(name).zip.
         """
-	if self.readonly:
+        if self.readonly:
             raise ProfileStorageException (_("Profile is read-only %s") %
                                            (self.name))
         self.__read_metadata ()
@@ -592,14 +592,32 @@ class ProfileStorage:
             save_zip.writestr ("metadata", self.metadata.serialize (format = 1))
 
             def zip_directory (save_zip, dir, name):
+                zip_filelist = save_zip.namelist()
+                homedir = util.get_home_dir()
+
                 for f in os.listdir (dir):
                     path = os.path.join (dir, f)
                     if os.path.isdir (path):
-                        zip_directory (save_zip,
-                                       path,
-                                       os.path.join (name, f))
+                        # We need to stop if we are recursing inside a ignored 
+                        # directory.
+                        if util.should_ignore_dir (homedir, 
+                                DIRECTORIES_TO_IGNORE, os.path.join(homedir, name, f)):
+                            dprint ("Not going inside %s as it is an ignored directory.", path)
+                        else:
+                            zip_directory (save_zip,
+                                        path,
+                                        os.path.join (name, f))
                     elif os.path.isfile (path):
-                        save_zip.write (path, os.path.join (name, f))
+                        # Avoid putting in a duplicate file entry
+                        # See bug #476761
+                        if os.path.join (name, f) in zip_filelist:
+                            dprint ("Not adding %s to zipfile since it is already in the file", os.path.join (name, f))
+                        elif util.should_ignore_file (homedir, 
+                                DIRECTORIES_TO_IGNORE, FILES_TO_IGNORE, os.path.join(homedir, name, f)):
+                            dprint ("Not adding %s to zipfile since it is a ignored file", os.path.join (name, f))
+                        else:
+                            zip_filelist.append(os.path.join(name, f))
+                            save_zip.write (path, os.path.join (name, f))
 
             def zip_foreach (path, is_directory, data):
                 (save_zip, temp_path) = data
